# Introduction 
Functions for working with Azure across HMT Data Science projects

# Getting Started
Clone and source the repo, or copy and paste a single function

# Contribute
Please do add functions or code snippets which could benefit others or you future self!

# Possible improvements
Making this a package for easier installation via pip



